summaryrefslogtreecommitdiffstats
path: root/perl-install/partition_table/empty.pm
diff options
context:
space:
mode:
authorPascal Rigaux <pixel@mandriva.com>2007-09-18 12:22:14 +0000
committerPascal Rigaux <pixel@mandriva.com>2007-09-18 12:22:14 +0000
commitf110caf7fb05213848c2d48fc4802b7d6babbed3 (patch)
tree6bb604ad22264f653f0766dfe38421d73d0212d4 /perl-install/partition_table/empty.pm
parentb0fb8e21570e7d8f5b874e002e2b6455aa92c7f3 (diff)
downloaddrakx-f110caf7fb05213848c2d48fc4802b7d6babbed3.tar
drakx-f110caf7fb05213848c2d48fc4802b7d6babbed3.tar.gz
drakx-f110caf7fb05213848c2d48fc4802b7d6babbed3.tar.bz2
drakx-f110caf7fb05213848c2d48fc4802b7d6babbed3.tar.xz
drakx-f110caf7fb05213848c2d48fc4802b7d6babbed3.zip
rename ->zero_MBR into ->clear, and ->zero_MBR_and_dirty into ->clear_and_dirty
(old name kept for compatibility)
Diffstat (limited to 'perl-install/partition_table/empty.pm')
-rw-r--r--perl-install/partition_table/empty.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perl-install/partition_table/empty.pm b/perl-install/partition_table/empty.pm
index e5d3c5685..fb2d8ada3 100644
--- a/perl-install/partition_table/empty.pm
+++ b/perl-install/partition_table/empty.pm
@@ -1,7 +1,7 @@
package partition_table::empty; # $Id$
#- this is a mainly dummy partition table. If we find it's empty, we just call -
#- zero_MBR which will take care of bless'ing us to the partition table type best
#- suited
@@ -28,7 +28,7 @@ sub read_one {
sysread $F, $tmp, 1024 or die "error reading magic number on disk $hd->{device}";
$tmp eq substr($tmp, 0, 1) x 1024 or die "bad magic number on disk $hd->{device}";
- partition_table::raw::zero_MBR($hd);
+ partition_table::raw::clear($hd);
$hd->{primary}{raw}, $hd->{primary}{info};
}
@@ -1,7 +1,7 @@
package partition_table::empty; # $Id$
#- this is a mainly dummy partition table. If we find it's empty, we just call -
-#- zero_MBR which will take care of bless'ing us to the partition table type best
+#- ->clear which will take care of bless'ing us to the partition table type best
#- suited